//-----------------------------------------------------------------------------
// seek.m
//
// Example of an Animated Seekbar
// created by RhinoTrip
//
// modified by FrisbeeMonkey
// (thanks Paikan for catching and fixing a bug!)
//-----------------------------------------------------------------------------



// Never forget to include std.mi
#include "D:\maki\mc\lib\std.mi"

//Declare local functions for use in script
Function initSeek();
Function updateSeeker(int x, int y);
Function setSeekerPosition(int p);

//Declare global variables for use in script
Global AnimatedLayer Seek;
Global Map seekMap;
Global Text SongTicker;
Global Timer SongTickerTimer, SongPlayingTimer;
Global Slider HiddenSeek;
Global Int SeekChanging, SeekFrames, LastSeek, TickerExist;

//When the script is loaded, do this
System.onScriptLoaded() {

	// Get the group that has the objects we want
	Group sGroup = getScriptGroup();

	// Now that we have the group, get the objects in the group
	Seek = sGroup.findObject("SeekAnim");
	HiddenSeek = sGroup.findObject("HiddenSeek");
	SongTicker = sGroup.findObject("SongTicker");

	// Initialize our timers
	SongTickerTimer = new Timer;
	SongTickerTimer.setDelay(1000);
	SongPlayingTimer = new Timer;
	SongPlayingTimer.setDelay(1000);

	// Load the gradient map
	seekMap = new Map;
	seekMap.loadMap("player.Map.Seek");

	// Intialize variables
	LastSeek = 0;
	SeekChanging = 0;
	SeekFrames = Seek.getLength();
	SeekFrames = SeekFrames - 1;
}


// Clears text area
SongTickerTimer.onTimer() {
	SongTicker.setText("");
	SongTickertimer.stop();
}

// Starts a timer to track the seeker position
System.onPlay() {
	SongPlayingTimer.start();
}

// Updates seeker as song plays
SongPlayingTimer.onTimer() {
	if (System.getPlayItemLength() > 0) {
		float p = System.getPosition();
		p = p / System.getPlayItemLength();
		p = p * 255;
		setSeekerPosition(p);
	}
}

// Stops moving seeker
System.onStop() {
	SongPlayingTimer.stop();
	Seek.gotoFrame(0);
}


// Reads clicks on seeker
Seek.onLeftButtonDown(int x, int y) {
	if (getPlayItemLength() > 0) {
		SongPlayingTimer.stop();
		SeekChanging = 1;
		updateSeeker(x, y);
	}
}

Seek.onLeftButtonUp(int x, int y) {
	Float l;
	if (SeekChanging) {
		l = seekMap.getValue(x - Seek.getLeft(), y - Seek.getTop());
		if (l > 0) {
			if (System.getPlayItemLength() >= 0) {
				l = (l / 255) * System.getPlayItemLength();
				System.seekTo(l);
			}
		}
		SongPlayingTimer.start();
		SeekChanging = 0;
	}
}

// Reads mouse movement of seeker
Seek.onMouseMove(int x, int y) {
	if (SeekChanging) {
		updateSeeker(x, y);
	}
}

// Updates seeker
updateSeeker(int x, int y) {
	int v = seekMap.getValue(x - Seek.getLeft(), y - Seek.getTop());
	if (v > 0) {
		setSeekerPosition(v);
		if (System.getPlayItemLength() >= 0) {
			float len = System.getPlayItemLength();
			int p = (v * 100) / 255;
			int s = (v * len) / 255;
			Songtickertimer.stop();
			Songtickertimer.start();
			Songticker.setText("Seek " + System.integerToTime(s) + " / " + System.integerToTime(len) + " (" + System.integerToString(p) + "%)");
		}
	}
}

// Moves seeker frame position
setSeekerPosition(int p) {
	int f = (p * SeekFrames) / 255;
    if (p > 0) {
		Seek.gotoFrame(f + 1);
	}
	if (p == 0) {
		Seek.gotoFrame(0);
	}
}

// Reads system position changes
HiddenSeek.onPostedPosition(int p) {
	if (p != LastSeek && !SeekChanging) {
		setSeekerPosition(p);
		LastSeek = p;
	}
}

System.onScriptUnloading() {
	delete SongTickerTimer;
	delete SongPlayingTimer;
	delete seekMap;
}