//-----------------------------------------------------------------------------
// volume.m
//
// Example of an animated volume
// based on seek.m created by RhinoTrip
//
// created by FrisbeeMonkey
//-----------------------------------------------------------------------------

#include "D:\maki\mc\lib\std.mi"

//declares volume functions
Function updateVolume(int v);

//declares global variables
Global AnimatedLayer Volume;
Global Map volMap;
Global Timer SongTickerTimer;
Global Text SongTicker;
Global Slider HiddenVolume;
Global Int VolChanging, VolFrames, VolFlag, TickerExist;
Global Group pcGroup;

//When the script is loaded, do this
System.onScriptLoaded() {

	// Get the group that has the objects we want
	pcGroup = getScriptGroup();

	// Now that we have the group, get the objects in the group
	Volume = pcGroup.findObject("VolumeAnimat");
	HiddenVolume = pcGroup.findObject("HiddenVolume");
	SongTicker = pcGroup.findObject("songticker");

	// Initialize our timer
	SongTickerTimer = new Timer;
	SongTickerTimer.setDelay(750);

	// Load the gradient map
	volMap = new Map;
	volMap.loadMap("player.map.volume");

	//initialize volume variables
	VolChanging = 0;
	VolFlag = 0;
    VolFrames = Volume.getLength();
    VolFrames = VolFrames - 1;

	// Set animated volume to current volume
	float u;
	u = System.getVolume();
	u = u / 255;
	u = u * VolFrames;
	Volume.gotoFrame(u);

}

// Clears text area
SongTickerTimer.onTimer() {
  SongTicker.setText("");
  SongTickerTimer.stop();
}

// Reads mouse drag on volume knob
Volume.onMouseMove(int x, int y) {
	if (VolChanging)  {
		x = x - Volume.getLeft();
		y = y - Volume.getTop();

		if (volMap.inRegion(x, y)) {
			float v = volMap.getValue(x, y);
			if (!VolFlag) {
				updateVolume(v);
				if (v > 245) {
					VolFlag = 2;
					updateVolume(255);
				}
				if (v < 10) {
					VolFlag = 1;
					updateVolume(0);
				}
			} else {
				if ((VolFlag == 2) && (v > 120) && (v < 252)) VolFlag = 0;
				if ((VolFlag == 1) && (v < 120) && (v > 2)) VolFlag = 0;
			}
        }
    }
}

// Reads mouse clicks on volume knob
Volume.onLeftButtonDown(int x, int y) {
	VolChanging = 1;
}

Volume.onLeftButtonUp(int x, int y) {
	if (VolChanging) {
		x = x - Volume.getLeft();
		y = y - Volume.getTop();

		if (volMap.inRegion(x, y)) {
			float v = volMap.getValue(x, y);
			if (!VolFlag) {
				updateVolume(v);
				if (v > 245) {
					VolFlag = 2;
					updateVolume(255);
				}
				if (v < 10) {
					VolFlag = 1;
					updateVolume(0);
				}
			} else {
				if ((VolFlag == 2) && (v > 120) && (v < 252)) VolFlag = 0;
				if ((VolFlag == 1) && (v < 120) && (v > 2)) VolFlag = 0;
			}
		}
		VolChanging = 0;
	}
}

// Updates Volume after drag/click
updateVolume(float v) {
	if (v >= 0) {
		float k = v / 255;
		int g = k * VolFrames;
		Volume.gotoFrame(g);
		System.setVolume(v);

		int p = k * 100;
		SongTickerTimer.stop();
		SongTickerTimer.start();
		SongTicker.setText("Vol " + System.integerToString(p) + "%");
     }
}

// Reads System Volume Changes
HiddenVolume.onPostedPosition(int p) {
	if (!VolChanging) {
		Float f = getVolume();
		f = f * VolFrames;
		f = f / 255;
		Volume.gotoFrame(f);
	}
}

System.onScriptUnloading() {
	delete SongTickerTimer;
	delete VolMap;
}